@@ -1,4 +1,8 @@
-__all__ = ('[SlimAdmin',)
+__title__ = 'slim.admin'
+__version__ = '0.3'
+__build__ = 0x000003
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('SlimAdmin',)
 
 from django.utils.translation import ugettext_lazy as _
 from django.contrib import admin
