@@ -1,9 +1,9 @@
 __title__ = 'slim.helpers'
-__version__ = '0.1'
-__build__ = 0x000001
+__version__ = '0.3'
+__build__ = 0x000003
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __all__ = ('get_default_language', 'default_language', 'get_languages', 'get_languages_keys', \
-           'get_language_from_request', 'smart_resolve')
+           'get_language_from_request', 'get_languages_dict', 'smart_resolve')
 
 from django.conf import settings
 
@@ -36,6 +36,15 @@ def get_languages_keys():
     return [key for key, name in get_languages()]
 
 
+def get_languages_dict():
+    """
+    Returns just languages dict.
+
+    :return dict:
+    """
+    return dict(settings.LANGUAGES)
+
+
 def get_language_from_request(request, default=default_language):
     """
     Gets language from HttpRequest
