@@ -1,3 +1,7 @@
+__title__ = 'slim.models.decorators'
+__version__ = '0.3'
+__build__ = 0x000003
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __all__ = ('prepend_language', 'localeurl_prepend_language', 'auto_prepend_language')
 
 from slim.utils import locale_url_is_installed
