@@ -1,9 +1,8 @@
 __title__ = 'slim.templatetags.slim_tags'
-__version__ = '0.1'
-__build__ = 0x000001
+__version__ = '0.3'
+__build__ = 0x000003
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__all__ = ('get_translated_object_for', 'get_translated_objects_for', 'set_language', 'get_language_name_by_key', \
-           'multiling_is_enabled')
+__all__ = ('get_translated_object_for', 'get_translated_objects_for', 'set_language', 'multiling_is_enabled')
 
 import re
 
@@ -13,6 +12,7 @@ from django.template import Library
 from django.utils import translation
 
 from slim.helpers import smart_resolve, default_language, get_language_from_request, get_languages_keys
+from slim.helpers import get_languages_dict
 
 register = Library()
 
@@ -211,69 +211,6 @@ def set_language(parser, token):
     return SetLanguageNode(language=language)
 
 
-class GetLanguageNameByKeyNode(template.Node):
-    """
-    Node for ``get_language_name_by_key`` tag.
-    """
-    def __init__(self, key, as_var=None, translate=False):
-        self.key = key
-        self.as_var = as_var
-        self.translate = translate
-
-    def render(self, context):
-        # Try to get request.LANGUAGE_CODE. If fail, use default one.
-        key = smart_resolve(self.key, context)
-        translate = smart_resolve(self.translate, context)
-        languages = dict(get_languages())
-
-        if languages.has_key(key):
-            ret_val = languages[key]
-        else:
-            ret_val = None
-
-        if translate:
-            ret_val = ugettext(ret_val)
-
-        if self.as_var:
-            context[self.as_var] = ret_val
-            return ''
-        return ret_val
-
-
-@register.tag
-def get_language_name_by_key(parser, token):
-    """
-    Gets language name by key given
-
-    FIXME: This is actually a hack.
-
-    Syntax::
-        {% get_language_name_by_key [key] [translate] as [var_name] %}
-    Example::
-        {% get_language_name_by_key ru translate as language_key %}
-    """
-    bits = token.contents.split()
-    if 5 < len(bits):
-        raise template.TemplateSyntaxError("'%s' tag takes five arguments at most" % bits[0])
-
-    key = parser.compile_filter(bits[1])
-
-    m = re.search(r'translate=(\d)', ' '.join(bits[2:-2]))
-
-    if m:
-        translate = parser.compile_filter(m.groups()[0])
-    else:
-        translate = None
-
-    if 'as' != bits[-2]:
-        raise template.TemplateSyntaxError(
-            _("Invalid syntax for %s. You must specify a name for translated object." % bits[0])
-            )
-    as_var = bits[-1]
-
-    return GetLanguageNameByKeyNode(key=key, as_var=as_var, translate=translate)
-
-
 class MultilinIsEnabledNode(template.Node):
     """
     Node for ``multiling_is_enabled`` tag.
@@ -319,3 +256,22 @@ def multiling_is_enabled(parser, token):
         as_var = None
 
     return MultilinIsEnabledNode(as_var=as_var)
+
+
+@register.filter
+def slim_language_name(lang_code):
+    """
+    Not all languages are available in Django yet. It might happen that support for your own precious language is
+    not yet available in Django and many apps rely on languages list defined in `django.conf.global_settings` module.
+
+    Thus, to have translations for your own language available, the following approach is introduced:
+    - Pick the language code closest to your language but name it differently: (('ar', ugettext('Armenian')),).
+    - Instead of using Django's `language_name` filter (of `i18n` module) use `slim_language_name` filter just the
+      same way.
+
+    This filter would get your item tranlation based on your project translations.
+
+    :param str lang_code:
+    :return str:
+    """
+    return _(get_languages_dict()[lang_code])
